#!/bin/sh

echo "+++++ Checking current user rights..."

if [ "$(id -u root)" = "$(id -u)" ] ; then
    :
else
    echo "ERROR: The current user id is not root (`id|awk '{print $1}'`)."
    exit 1
fi
echo

if [ "X$PVSW_ROOT" = "X" ] ; then
    PVSW_ROOT=/usr/local/psql
fi

echo "+++++ Removing PSQL directories..."
####################################################################
#  Note: Any changes to the files to be removed must be made to the 
#        corresponding PSQL-Clients-Linux.spec file %postun section. 
####################################################################
HOMEDIR=`grep "^psql:" /etc/passwd | cut -d: -f6`
rm -f $HOMEDIR/.cshrc
rm -f $HOMEDIR/.bash_profile
rm -f $HOMEDIR/.bash_history
rm -f $HOMEDIR/.bashrc
rm -f  $PVSW_ROOT/LICENSE
rm -f  $PVSW_ROOT/PSQL_Third_Party_Notice
rm -f  $PVSW_ROOT/etc/client*.sh
rm -f  $PVSW_ROOT/etc/postinstall.cfg
rm -f  $PVSW_ROOT/etc/psql-unixODBC-2.2.11.tar.gz
rm -Rf $PVSW_ROOT/bin
rm -Rf $PVSW_ROOT/jre
rm -Rf $PVSW_ROOT/lib
rm -Rf $PVSW_ROOT/lib64
rm -Rf $PVSW_ROOT/man
rm -Rf $PVSW_ROOT/docs
rm -Rf $PVSW_ROOT/log
echo ""

# If this is Darwin.
if [ $(uname -s) = "Darwin" ]
then
    APPLICATIONS="/Applications"

    # If there is an applications directory.
    if [ -d "$APPLICATIONS" ]
    then
        ACTIAN_PSQL_13="$APPLICATIONS/Actian PSQL 13"
        UTILITIES="$ACTIAN_PSQL_13/Utilities"
        echo "+++++ Unpopulating the \"$ACTIAN_PSQL_13\" directory...."
        ERROR=0

        # If removing "PSQL DDF Builder.app" fails.
        if ! rm -r "$UTILITIES/PSQL DDF Builder.app"
        then
            ERROR=1
        fi

        # If removing ".DS_Store" fails.
        if ! rm -f "$UTILITIES/.DS_Store"
        then
            ERROR=1
        fi

        # If removing "$UTILITIES" fails.
        if ! rmdir "$UTILITIES"
        then
            ERROR=1
        fi

        # If removing "PSQL Control Center.app" fails.
        if ! rm -r "$ACTIAN_PSQL_13/PSQL Control Center.app"
        then
            ERROR=1
        fi

        # If removing "PSQL Uninstall.app" fails.
        if ! rm -r "$ACTIAN_PSQL_13/PSQL Uninstall.app" || ! rm "$ACTIAN_PSQL_13/.uninstall"
        then
            ERROR=1
        fi

        # If removing "messages" fails.
        if ! rm "$ACTIAN_PSQL_13/.messages"
        then
            ERROR=1
        fi

        # If removing ".DS_Store" fails.
        if ! rm -f "$ACTIAN_PSQL_13/.DS_Store"
        then
            ERROR=1
        fi

        # If removing "$ACTIAN_PSQL_13" fails.
        if ! rmdir "$ACTIAN_PSQL_13"
        then
            ERROR=1
        fi

        # If there were any errors.
        if [ "$ERROR" -eq 1 ]
        then
            echo "Error: Unable to correctly unpopulate the \"$ACTIAN_PSQL_13\" directory."
            exit 1
        fi

        echo
    fi
fi

echo "Uninstall has successfully completed."
echo



















