#!/bin/sh

echo "+++++ Checking current user rights..."

if [ "$(id -u root)" = "$(id -u)" ] ; then
    echo "Passed..."
else
    echo "ERROR: The current user id is not root (`id|awk '{print $1}'`)."
    exit 1
fi
echo


if [ "X$PVSW_ROOT" = "X" ] ; then
    PVSW_ROOT=/usr/local/psql
fi
PATH=$PVSW_ROOT/bin:$PATH
if [ $(uname -s) = "Darwin" ]
then
    DYLD_LIBRARY_PATH=$PVSW_ROOT/bin:$PVSW_ROOT/lib:$PVSW_ROOT/lib64:$DYLD_LIBRARY_PATH
    export DYLD_LIBRARY_PATH
    SO_EXTENSION="dylib"
else
    LD_LIBRARY_PATH=$PVSW_ROOT/bin:$PVSW_ROOT/lib64:$LD_LIBRARY_PATH
    SO_EXTENSION="so"
fi


echo "+++++ Checking for previous installs..."

if [ -f /usr/local/psql/bin/mkded ] ; then
    echo "ERROR: 64-bit Server already installed.  Uninstall PSQL Server to proceed with client install."
    exit 1
fi
echo "Passed..."
echo


echo "+++++ Checking for system dependencies..."

# Default values assume 64-bit is x86_64 and 32-bit is x86.
ELF64_TEXT="ELF 64-bit LSB"
ELF64_LIB="/lib64/ld-linux-x86-64.${SO_EXTENSION}.2"
ELF32_TEXT="ELF 32-bit LSB"
ELF32_LIB="/lib/ld-linux.${SO_EXTENSION}.2"

UNAME_PROC=`uname -mp`
echo $UNAME_PROC | grep "aarch64" >/dev/null
if [ $? -eq 0 ] ; then
    # 64-bit ARM
    ELF64_LIB="/lib64/ld-linux-aarch64.${SO_EXTENSION}.1"
fi
echo $UNAME_PROC | grep "armv" >/dev/null
if [ $? -eq 0 ] ; then
    # 32-bit ARM
    ELF32_LIB="/lib/ld-linux-armhf.${SO_EXTENSION}.3"
fi

if [ $(uname -s) != "Darwin" ]
then
    if [ -f /usr/local/psql/lib/libpsqlmif.${SO_EXTENSION}.* ] ; then
        file -L $ELF32_LIB | grep "$ELF32_TEXT" >/dev/null 2>&1
        if [ $? -ne 0 ] ; then
            echo "ERROR: $ELF32_LIB not found. This package requires 32-bit runtime library support."
            exit 1
        fi
    fi
    if [ -f /usr/local/psql/lib64/libpsqlmif.${SO_EXTENSION}.* ] ; then
        file -L $ELF64_LIB | grep "$ELF64_TEXT" >/dev/null 2>&1
        if [ $? -ne 0 ] ; then
            echo "ERROR: $ELF64_LIB not found. This package requires 64-bit runtime library support."
            exit 1
        fi
    fi

fi

echo "Passed..."
echo
